# -*- coding: utf-8
"""
select {} on columns,
      [Geschlecht].[Geschlecht].[Level 01].ALLMEMBERS on rows
from [fused]

"""

result={'Axes': {'Axis': [{'Tuples': None, '_name': 'Axis0'},
                   {'Tuples': {'Tuple': [{'Member': {'Caption': 'weiblich',
                                                     'DisplayInfo': '0',
                                                     'LName': '[Geschlecht].[Geschlecht].[Level '
                                                              '01]',
                                                     'LNum': '1',
                                                     'UName': '[Geschlecht].[Geschlecht].[weiblich]',
                                                     '_Hierarchy': '[Geschlecht].[Geschlecht]'}},
                                         {'Member': {'Caption': 'männlich',
                                                     'DisplayInfo': '131072',
                                                     'LName': '[Geschlecht].[Geschlecht].[Level '
                                                              '01]',
                                                     'LNum': '1',
                                                     'UName': '[Geschlecht].[Geschlecht].[männlich]',
                                                     '_Hierarchy': '[Geschlecht].[Geschlecht]'}}]},
                    '_name': 'Axis1'},
                   {'Tuples': {'Tuple': {'Member': [{'Caption': 'Mitarbeiteranzahl',
                                                     'DisplayInfo': '0',
                                                     'LName': '[Measures].[MeasuresLevel]',
                                                     'LNum': '0',
                                                     'UName': '[Measures].[Mitarbeiteranzahl]',
                                                     '_Hierarchy': '[Measures]'},
                                                    {'Caption': 'Alle',
                                                     'DisplayInfo': '11',
                                                     'LName': '[Zeit].[Monate].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Zeit].[Monate].[Alle]',
                                                     '_Hierarchy': '[Zeit].[Monate]'},
                                                    {'Caption': 'Zeit Gesamt',
                                                     'DisplayInfo': '11',
                                                     'LName': '[Zeit].[Zeit].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Zeit].[Zeit].[Zeit '
                                                              'Gesamt]',
                                                     '_Hierarchy': '[Zeit].[Zeit]'},
                                                    {'Caption': 'Alle '
                                                                'Vertragsbefristungen',
                                                     'DisplayInfo': '2',
                                                     'LName': '[Vertragsbefristung].[Vertragsbefristung].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Vertragsbefristung].[Vertragsbefristung].[Alle '
                                                              'Vertragsbefristungen]',
                                                     '_Hierarchy': '[Vertragsbefristung].[Vertragsbefristung]'},
                                                    {'Caption': 'Alle '
                                                                'Mitarbeitergruppen',
                                                     'DisplayInfo': '5',
                                                     'LName': '[Mitarbeitergruppe].[Mitarbeitergruppe].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Mitarbeitergruppe].[Mitarbeitergruppe].[Alle '
                                                              'Mitarbeitergruppen]',
                                                     '_Hierarchy': '[Mitarbeitergruppe].[Mitarbeitergruppe]'},
                                                    {'Caption': 'Alle',
                                                     'DisplayInfo': '7',
                                                     'LName': '[Funktionsbezeichnung].[Funktionsbezeichnung].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Funktionsbezeichnung].[Funktionsbezeichnung].[Alle]',
                                                     '_Hierarchy': '[Funktionsbezeichnung].[Funktionsbezeichnung]'},
                                                    {'Caption': 'jedes Alter',
                                                     'DisplayInfo': '9',
                                                     'LName': '[Alter].[Alter].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Alter].[Alter].[jedes '
                                                              'Alter]',
                                                     '_Hierarchy': '[Alter].[Alter]'},
                                                    {'Caption': 'Alle '
                                                                'Vertragsarten',
                                                     'DisplayInfo': '53',
                                                     'LName': '[Vertragsart].[Vertragsart].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Vertragsart].[Vertragsart].[Alle '
                                                              'Vertragsarten]',
                                                     '_Hierarchy': '[Vertragsart].[Vertragsart]'},
                                                    {'Caption': 'Alle '
                                                                'Betriebszugehörigkeiten',
                                                     'DisplayInfo': '10',
                                                     'LName': '[Betriebszugehörigkeit].[Betriebszugehörigkeit].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Betriebszugehörigkeit].[Betriebszugehörigkeit].[Alle '
                                                              'Betriebszugehörigkeiten]',
                                                     '_Hierarchy': '[Betriebszugehörigkeit].[Betriebszugehörigkeit]'},
                                                    {'Caption': 'Alle '
                                                                'Standorte',
                                                     'DisplayInfo': '3',
                                                     'LName': '[Standort].[Standort].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Standort].[Standort].[Alle '
                                                              'Standorte]',
                                                     '_Hierarchy': '[Standort].[Standort]'},
                                                    {'Caption': 'AP',
                                                     'DisplayInfo': '0',
                                                     'LName': '[Zeitbetrachtung].[Zeitbetrachtung].[Zeitbetrachtung]',
                                                     'LNum': '0',
                                                     'UName': '[Zeitbetrachtung].[Zeitbetrachtung].[AP]',
                                                     '_Hierarchy': '[Zeitbetrachtung].[Zeitbetrachtung]'},
                                                    {'Caption': ' '
                                                                'Kieback&Peter '
                                                                'GmbH & Co.KG',
                                                     'DisplayInfo': '6',
                                                     'LName': '[Kostenstelle].[Kostenstelle].[Top]',
                                                     'LNum': '0',
                                                     'UName': '[Kostenstelle].[Kostenstelle].[ '
                                                              'Kieback&Peter '
                                                              'GmbH & Co.KG]',
                                                     '_Hierarchy': '[Kostenstelle].[Kostenstelle]'},
                                                    {'Caption': 'All',
                                                     'DisplayInfo': '2586',
                                                     'LName': '[Kostenstelle].[PNR].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Kostenstelle].[PNR].[All]',
                                                     '_Hierarchy': '[Kostenstelle].[PNR]'},
                                                    {'Caption': 'All',
                                                     'DisplayInfo': '456',
                                                     'LName': '[Kostenstelle].[Eintritt2].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Kostenstelle].[Eintritt2].[All]',
                                                     '_Hierarchy': '[Kostenstelle].[Eintritt2]'},
                                                    {'Caption': 'All',
                                                     'DisplayInfo': '456',
                                                     'LName': '[Kostenstelle].[Eintritt].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Kostenstelle].[Eintritt].[All]',
                                                     '_Hierarchy': '[Kostenstelle].[Eintritt]'},
                                                    {'Caption': 'KST Gesamt',
                                                     'DisplayInfo': '374',
                                                     'LName': '[KST].[KST].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[KST].[KST].[KST '
                                                              'Gesamt]',
                                                     '_Hierarchy': '[KST].[KST]'},
                                                    {'Caption': 'All',
                                                     'DisplayInfo': '2586',
                                                     'LName': '[Person].[Person].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Person].[Person].[All]',
                                                     '_Hierarchy': '[Person].[Person]'},
                                                    {'Caption': 'Alle Personen',
                                                     'DisplayInfo': '254',
                                                     'LName': '[Person].[Person '
                                                              'Austritt].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Person].[Person '
                                                              'Austritt].[Alle '
                                                              'Personen]',
                                                     '_Hierarchy': '[Person].[Person '
                                                                   'Austritt]'},
                                                    {'Caption': 'Alle Personen',
                                                     'DisplayInfo': '3',
                                                     'LName': '[Person].[Person '
                                                              'aktiv].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Person].[Person '
                                                              'aktiv].[Alle '
                                                              'Personen]',
                                                     '_Hierarchy': '[Person].[Person '
                                                                   'aktiv]'},
                                                    {'Caption': 'All',
                                                     'DisplayInfo': '65',
                                                     'LName': '[UserAccount].[UserAccount].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[UserAccount].[UserAccount].[All]',
                                                     '_Hierarchy': '[UserAccount].[UserAccount]'},
                                                    {'Caption': 'All',
                                                     'DisplayInfo': '65',
                                                     'LName': '[UserAccount].[Level '
                                                              '01 '
                                                              'username].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[UserAccount].[Level '
                                                              '01 '
                                                              'username].[All]',
                                                     '_Hierarchy': '[UserAccount].[Level '
                                                                   '01 '
                                                                   'username]'},
                                                    {'Caption': 'All',
                                                     'DisplayInfo': '65',
                                                     'LName': '[UserAccount].[Level '
                                                              '01 '
                                                              'shortusername].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[UserAccount].[Level '
                                                              '01 '
                                                              'shortusername].[All]',
                                                     '_Hierarchy': '[UserAccount].[Level '
                                                                   '01 '
                                                                   'shortusername]'},
                                                    {'Caption': 'Alle',
                                                     'DisplayInfo': '10',
                                                     'LName': '[Vertragszustand].[Vertragszustand].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Vertragszustand].[Vertragszustand].[Alle]',
                                                     '_Hierarchy': '[Vertragszustand].[Vertragszustand]'},
                                                    {'Caption': 'Alle '
                                                                'Kostenarten',
                                                     'DisplayInfo': '5',
                                                     'LName': '[Kostenart].[Kostenart].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Kostenart].[Kostenart].[Alle '
                                                              'Kostenarten]',
                                                     '_Hierarchy': '[Kostenart].[Kostenart]'},
                                                    {'Caption': 'Alle '
                                                                'Kostenarten',
                                                     'DisplayInfo': '51',
                                                     'LName': '[Kostenart].[Level '
                                                              '02 '
                                                              'Bezeichnung].[(All)]',
                                                     'LNum': '0',
                                                     'UName': '[Kostenart].[Level '
                                                              '02 '
                                                              'Bezeichnung].[Alle '
                                                              'Kostenarten]',
                                                     '_Hierarchy': '[Kostenart].[Level '
                                                                   '02 '
                                                                   'Bezeichnung]'}]}},
                    '_name': 'SlicerAxis'}]},
 'CellData': None,
 'OlapInfo': {'AxesInfo': {'AxisInfo': [{'_name': 'Axis0'},
                                        {'HierarchyInfo': {'Caption': {'_name': '[Geschlecht].[Geschlecht].[MEMBER_CAPTION]',
                                                                       '_type': 'xsd:string'},
                                                           'DisplayInfo': {'_name': '[Geschlecht].[Geschlecht].[DISPLAY_INFO]',
                                                                           '_type': 'xsd:unsignedInt'},
                                                           'LName': {'_name': '[Geschlecht].[Geschlecht].[LEVEL_UNIQUE_NAME]',
                                                                     '_type': 'xsd:string'},
                                                           'LNum': {'_name': '[Geschlecht].[Geschlecht].[LEVEL_NUMBER]',
                                                                    '_type': 'xsd:int'},
                                                           'UName': {'_name': '[Geschlecht].[Geschlecht].[MEMBER_UNIQUE_NAME]',
                                                                     '_type': 'xsd:string'},
                                                           '_name': '[Geschlecht].[Geschlecht]'},
                                         '_name': 'Axis1'},
                                        {'HierarchyInfo': [{'Caption': {'_name': '[Measures].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Measures].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Measures].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Measures].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Measures].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Measures]'},
                                                           {'Caption': {'_name': '[Zeit].[Monate].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Zeit].[Monate].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Zeit].[Monate].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Zeit].[Monate].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Zeit].[Monate].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Zeit].[Monate]'},
                                                           {'Caption': {'_name': '[Zeit].[Zeit].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Zeit].[Zeit].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Zeit].[Zeit].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Zeit].[Zeit].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Zeit].[Zeit].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Zeit].[Zeit]'},
                                                           {'Caption': {'_name': '[Vertragsbefristung].[Vertragsbefristung].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Vertragsbefristung].[Vertragsbefristung].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Vertragsbefristung].[Vertragsbefristung].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Vertragsbefristung].[Vertragsbefristung].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Vertragsbefristung].[Vertragsbefristung].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Vertragsbefristung].[Vertragsbefristung]'},
                                                           {'Caption': {'_name': '[Mitarbeitergruppe].[Mitarbeitergruppe].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Mitarbeitergruppe].[Mitarbeitergruppe].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Mitarbeitergruppe].[Mitarbeitergruppe].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Mitarbeitergruppe].[Mitarbeitergruppe].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Mitarbeitergruppe].[Mitarbeitergruppe].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Mitarbeitergruppe].[Mitarbeitergruppe]'},
                                                           {'Caption': {'_name': '[Funktionsbezeichnung].[Funktionsbezeichnung].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Funktionsbezeichnung].[Funktionsbezeichnung].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Funktionsbezeichnung].[Funktionsbezeichnung].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Funktionsbezeichnung].[Funktionsbezeichnung].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Funktionsbezeichnung].[Funktionsbezeichnung].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Funktionsbezeichnung].[Funktionsbezeichnung]'},
                                                           {'Caption': {'_name': '[Alter].[Alter].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Alter].[Alter].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Alter].[Alter].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Alter].[Alter].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Alter].[Alter].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Alter].[Alter]'},
                                                           {'Caption': {'_name': '[Vertragsart].[Vertragsart].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Vertragsart].[Vertragsart].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Vertragsart].[Vertragsart].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Vertragsart].[Vertragsart].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Vertragsart].[Vertragsart].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Vertragsart].[Vertragsart]'},
                                                           {'Caption': {'_name': '[Betriebszugehörigkeit].[Betriebszugehörigkeit].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Betriebszugehörigkeit].[Betriebszugehörigkeit].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Betriebszugehörigkeit].[Betriebszugehörigkeit].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Betriebszugehörigkeit].[Betriebszugehörigkeit].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Betriebszugehörigkeit].[Betriebszugehörigkeit].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Betriebszugehörigkeit].[Betriebszugehörigkeit]'},
                                                           {'Caption': {'_name': '[Standort].[Standort].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Standort].[Standort].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Standort].[Standort].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Standort].[Standort].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Standort].[Standort].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Standort].[Standort]'},
                                                           {'Caption': {'_name': '[Zeitbetrachtung].[Zeitbetrachtung].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Zeitbetrachtung].[Zeitbetrachtung].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Zeitbetrachtung].[Zeitbetrachtung].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Zeitbetrachtung].[Zeitbetrachtung].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Zeitbetrachtung].[Zeitbetrachtung].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Zeitbetrachtung].[Zeitbetrachtung]'},
                                                           {'Caption': {'_name': '[Kostenstelle].[Kostenstelle].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Kostenstelle].[Kostenstelle].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Kostenstelle].[Kostenstelle].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Kostenstelle].[Kostenstelle].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Kostenstelle].[Kostenstelle].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Kostenstelle].[Kostenstelle]'},
                                                           {'Caption': {'_name': '[Kostenstelle].[PNR].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Kostenstelle].[PNR].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Kostenstelle].[PNR].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Kostenstelle].[PNR].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Kostenstelle].[PNR].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Kostenstelle].[PNR]'},
                                                           {'Caption': {'_name': '[Kostenstelle].[Eintritt2].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Kostenstelle].[Eintritt2].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Kostenstelle].[Eintritt2].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Kostenstelle].[Eintritt2].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Kostenstelle].[Eintritt2].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Kostenstelle].[Eintritt2]'},
                                                           {'Caption': {'_name': '[Kostenstelle].[Eintritt].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Kostenstelle].[Eintritt].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Kostenstelle].[Eintritt].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Kostenstelle].[Eintritt].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Kostenstelle].[Eintritt].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Kostenstelle].[Eintritt]'},
                                                           {'Caption': {'_name': '[KST].[KST].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[KST].[KST].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[KST].[KST].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[KST].[KST].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[KST].[KST].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[KST].[KST]'},
                                                           {'Caption': {'_name': '[Person].[Person].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Person].[Person].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Person].[Person].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Person].[Person].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Person].[Person].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Person].[Person]'},
                                                           {'Caption': {'_name': '[Person].[Person '
                                                                                 'Austritt].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Person].[Person '
                                                                                     'Austritt].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Person].[Person '
                                                                               'Austritt].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Person].[Person '
                                                                              'Austritt].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Person].[Person '
                                                                               'Austritt].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Person].[Person '
                                                                     'Austritt]'},
                                                           {'Caption': {'_name': '[Person].[Person '
                                                                                 'aktiv].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Person].[Person '
                                                                                     'aktiv].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Person].[Person '
                                                                               'aktiv].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Person].[Person '
                                                                              'aktiv].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Person].[Person '
                                                                               'aktiv].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Person].[Person '
                                                                     'aktiv]'},
                                                           {'Caption': {'_name': '[UserAccount].[UserAccount].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[UserAccount].[UserAccount].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[UserAccount].[UserAccount].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[UserAccount].[UserAccount].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[UserAccount].[UserAccount].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[UserAccount].[UserAccount]'},
                                                           {'Caption': {'_name': '[UserAccount].[Level '
                                                                                 '01 '
                                                                                 'username].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[UserAccount].[Level '
                                                                                     '01 '
                                                                                     'username].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[UserAccount].[Level '
                                                                               '01 '
                                                                               'username].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[UserAccount].[Level '
                                                                              '01 '
                                                                              'username].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[UserAccount].[Level '
                                                                               '01 '
                                                                               'username].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[UserAccount].[Level '
                                                                     '01 '
                                                                     'username]'},
                                                           {'Caption': {'_name': '[UserAccount].[Level '
                                                                                 '01 '
                                                                                 'shortusername].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[UserAccount].[Level '
                                                                                     '01 '
                                                                                     'shortusername].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[UserAccount].[Level '
                                                                               '01 '
                                                                               'shortusername].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[UserAccount].[Level '
                                                                              '01 '
                                                                              'shortusername].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[UserAccount].[Level '
                                                                               '01 '
                                                                               'shortusername].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[UserAccount].[Level '
                                                                     '01 '
                                                                     'shortusername]'},
                                                           {'Caption': {'_name': '[Vertragszustand].[Vertragszustand].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Vertragszustand].[Vertragszustand].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Vertragszustand].[Vertragszustand].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Vertragszustand].[Vertragszustand].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Vertragszustand].[Vertragszustand].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Vertragszustand].[Vertragszustand]'},
                                                           {'Caption': {'_name': '[Kostenart].[Kostenart].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Kostenart].[Kostenart].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Kostenart].[Kostenart].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Kostenart].[Kostenart].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Kostenart].[Kostenart].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Kostenart].[Kostenart]'},
                                                           {'Caption': {'_name': '[Kostenart].[Level '
                                                                                 '02 '
                                                                                 'Bezeichnung].[MEMBER_CAPTION]',
                                                                        '_type': 'xsd:string'},
                                                            'DisplayInfo': {'_name': '[Kostenart].[Level '
                                                                                     '02 '
                                                                                     'Bezeichnung].[DISPLAY_INFO]',
                                                                            '_type': 'xsd:unsignedInt'},
                                                            'LName': {'_name': '[Kostenart].[Level '
                                                                               '02 '
                                                                               'Bezeichnung].[LEVEL_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            'LNum': {'_name': '[Kostenart].[Level '
                                                                              '02 '
                                                                              'Bezeichnung].[LEVEL_NUMBER]',
                                                                     '_type': 'xsd:int'},
                                                            'UName': {'_name': '[Kostenart].[Level '
                                                                               '02 '
                                                                               'Bezeichnung].[MEMBER_UNIQUE_NAME]',
                                                                      '_type': 'xsd:string'},
                                                            '_name': '[Kostenart].[Level '
                                                                     '02 '
                                                                     'Bezeichnung]'}],
                                         '_name': 'SlicerAxis'}]},
              'CellInfo': {'CellOrdinal': {'_name': 'CELL_ORDINAL',
                                           '_type': 'xsd:unsignedInt'},
                           'FmtValue': {'_name': 'FORMATTED_VALUE',
                                        '_type': 'xsd:string'},
                           'Value': {'_name': 'VALUE'}},
              'CubeInfo': {'Cube': {'CubeName': 'fused'}}}}

xml_response="""<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/">
  <soap:Body>
    <ExecuteResponse xmlns="urn:schemas-microsoft-com:xml-analysis">
      <return>
        <root xmlns="urn:schemas-microsoft-com:xml-analysis:mddataset" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla">
          <xs:schema xmlns="urn:schemas-microsoft-com:xml-analysis:mddataset" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:msxmla="http://schemas.microsoft.com/analysisservices/2003/xmla" targetNamespace="urn:schemas-microsoft-com:xml-analysis:mddataset" elementFormDefault="qualified">
            <xs:import namespace="http://schemas.microsoft.com/analysisservices/2003/xmla"/>
            <xs:complexType name="MemberType">
              <xs:sequence>
                <xs:any namespace="##targetNamespace" minOccurs="0" maxOccurs="unbounded" processContents="skip"/>
              </xs:sequence>
              <xs:attribute name="Hierarchy" type="xs:string"/>
            </xs:complexType>
            <xs:complexType name="PropType">
              <xs:sequence>
                <xs:element name="Default" minOccurs="0"/>
              </xs:sequence>
              <xs:attribute name="name" type="xs:string" use="required"/>
              <xs:attribute name="type" type="xs:QName"/>
            </xs:complexType>
            <xs:complexType name="TupleType">
              <xs:sequence>
                <xs:element name="Member" type="MemberType" minOccurs="0" maxOccurs="unbounded"/>
              </xs:sequence>
            </xs:complexType>
            <xs:complexType name="MembersType">
              <xs:sequence>
                <xs:element name="Member" type="MemberType" minOccurs="0" maxOccurs="unbounded"/>
              </xs:sequence>
              <xs:attribute name="Hierarchy" type="xs:string" use="required"/>
            </xs:complexType>
            <xs:complexType name="TuplesType">
              <xs:sequence>
                <xs:element name="Tuple" type="TupleType" minOccurs="0" maxOccurs="unbounded"/>
              </xs:sequence>
            </xs:complexType>
            <xs:group name="SetType">
              <xs:choice>
                <xs:element name="Members" type="MembersType"/>
                <xs:element name="Tuples" type="TuplesType"/>
                <xs:element name="CrossProduct" type="SetListType"/>
                <xs:element ref="msxmla:NormTupleSet"/>
                <xs:element name="Union">
                  <xs:complexType>
                    <xs:group ref="SetType" minOccurs="0" maxOccurs="unbounded"/>
                  </xs:complexType>
                </xs:element>
              </xs:choice>
            </xs:group>
            <xs:complexType name="SetListType">
              <xs:group ref="SetType" minOccurs="0" maxOccurs="unbounded"/>
              <xs:attribute name="Size" type="xs:unsignedInt"/>
            </xs:complexType>
            <xs:complexType name="OlapInfo">
              <xs:sequence>
                <xs:element name="CubeInfo">
                  <xs:complexType>
                    <xs:sequence>
                      <xs:element name="Cube" maxOccurs="unbounded">
                        <xs:complexType>
                          <xs:sequence>
                            <xs:element name="CubeName" type="xs:string"/>
                            <xs:element name="LastDataUpdate" minOccurs="0" type="xs:dateTime"/>
                            <xs:element name="LastSchemaUpdate" minOccurs="0" type="xs:dateTime"/>
                          </xs:sequence>
                        </xs:complexType>
                      </xs:element>
                    </xs:sequence>
                  </xs:complexType>
                </xs:element>
                <xs:element name="AxesInfo">
                  <xs:complexType>
                    <xs:sequence>
                      <xs:element name="AxisInfo" maxOccurs="unbounded">
                        <xs:complexType>
                          <xs:sequence>
                            <xs:element name="HierarchyInfo" minOccurs="0" maxOccurs="unbounded">
                              <xs:complexType>
                                <xs:sequence>
                                  <xs:any namespace="##targetNamespace" minOccurs="0" maxOccurs="unbounded" processContents="skip"/>
                                </xs:sequence>
                                <xs:attribute name="name" type="xs:string" use="required"/>
                              </xs:complexType>
                            </xs:element>
                          </xs:sequence>
                          <xs:attribute name="name" type="xs:string"/>
                        </xs:complexType>
                      </xs:element>
                    </xs:sequence>
                  </xs:complexType>
                </xs:element>
                <xs:element name="CellInfo">
                  <xs:complexType>
                    <xs:choice minOccurs="0" maxOccurs="unbounded">
                      <xs:any namespace="##targetNamespace" minOccurs="0" maxOccurs="unbounded" processContents="skip"/>
                    </xs:choice>
                  </xs:complexType>
                </xs:element>
              </xs:sequence>
            </xs:complexType>
            <xs:complexType name="Axes">
              <xs:sequence>
                <xs:element name="Axis" maxOccurs="unbounded">
                  <xs:complexType>
                    <xs:group ref="SetType" minOccurs="0" maxOccurs="unbounded"/>
                    <xs:attribute name="name" type="xs:string"/>
                  </xs:complexType>
                </xs:element>
              </xs:sequence>
            </xs:complexType>
            <xs:complexType name="CellData">
              <xs:sequence>
                <xs:element name="Cell" minOccurs="0" maxOccurs="unbounded">
                  <xs:complexType>
                    <xs:sequence>
                      <xs:any namespace="##targetNamespace" minOccurs="0" maxOccurs="unbounded" processContents="skip"/>
                    </xs:sequence>
                    <xs:attribute name="CellOrdinal" type="xs:unsignedInt" use="required"/>
                  </xs:complexType>
                </xs:element>
              </xs:sequence>
            </xs:complexType>
            <xs:element name="root">
              <xs:complexType>
                <xs:sequence>
                  <xs:any namespace="http://www.w3.org/2001/XMLSchema" processContents="strict" minOccurs="0"/>
                  <xs:element name="OlapInfo" type="OlapInfo" minOccurs="0"/>
                  <xs:element name="Axes" type="Axes" minOccurs="0"/>
                  <xs:element name="CellData" type="CellData" minOccurs="0"/>
                </xs:sequence>
              </xs:complexType>
            </xs:element>
          </xs:schema>
          <OlapInfo>
            <CubeInfo>
              <Cube>
                <CubeName>fused</CubeName>
                <LastDataUpdate xmlns="http://schemas.microsoft.com/analysisservices/2003/engine">2019-04-05T06:44:33.583333</LastDataUpdate>
                <LastSchemaUpdate xmlns="http://schemas.microsoft.com/analysisservices/2003/engine">2019-04-05T06:44:30.223333</LastSchemaUpdate>
              </Cube>
            </CubeInfo>
            <AxesInfo>
              <AxisInfo name="Axis0"/>
              <AxisInfo name="Axis1">
                <HierarchyInfo name="[Geschlecht].[Geschlecht]">
                  <UName name="[Geschlecht].[Geschlecht].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Geschlecht].[Geschlecht].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Geschlecht].[Geschlecht].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Geschlecht].[Geschlecht].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Geschlecht].[Geschlecht].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
              </AxisInfo>
              <AxisInfo name="SlicerAxis">
                <HierarchyInfo name="[Measures]">
                  <UName name="[Measures].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Measures].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Measures].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Measures].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Measures].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Zeit].[Monate]">
                  <UName name="[Zeit].[Monate].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Zeit].[Monate].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Zeit].[Monate].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Zeit].[Monate].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Zeit].[Monate].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Zeit].[Zeit]">
                  <UName name="[Zeit].[Zeit].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Zeit].[Zeit].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Zeit].[Zeit].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Zeit].[Zeit].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Zeit].[Zeit].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Vertragsbefristung].[Vertragsbefristung]">
                  <UName name="[Vertragsbefristung].[Vertragsbefristung].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Vertragsbefristung].[Vertragsbefristung].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Vertragsbefristung].[Vertragsbefristung].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Vertragsbefristung].[Vertragsbefristung].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Vertragsbefristung].[Vertragsbefristung].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Mitarbeitergruppe].[Mitarbeitergruppe]">
                  <UName name="[Mitarbeitergruppe].[Mitarbeitergruppe].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Mitarbeitergruppe].[Mitarbeitergruppe].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Mitarbeitergruppe].[Mitarbeitergruppe].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Mitarbeitergruppe].[Mitarbeitergruppe].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Mitarbeitergruppe].[Mitarbeitergruppe].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Funktionsbezeichnung].[Funktionsbezeichnung]">
                  <UName name="[Funktionsbezeichnung].[Funktionsbezeichnung].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Funktionsbezeichnung].[Funktionsbezeichnung].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Funktionsbezeichnung].[Funktionsbezeichnung].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Funktionsbezeichnung].[Funktionsbezeichnung].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Funktionsbezeichnung].[Funktionsbezeichnung].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Alter].[Alter]">
                  <UName name="[Alter].[Alter].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Alter].[Alter].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Alter].[Alter].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Alter].[Alter].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Alter].[Alter].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Vertragsart].[Vertragsart]">
                  <UName name="[Vertragsart].[Vertragsart].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Vertragsart].[Vertragsart].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Vertragsart].[Vertragsart].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Vertragsart].[Vertragsart].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Vertragsart].[Vertragsart].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit]">
                  <UName name="[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Standort].[Standort]">
                  <UName name="[Standort].[Standort].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Standort].[Standort].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Standort].[Standort].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Standort].[Standort].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Standort].[Standort].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Zeitbetrachtung].[Zeitbetrachtung]">
                  <UName name="[Zeitbetrachtung].[Zeitbetrachtung].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Zeitbetrachtung].[Zeitbetrachtung].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Zeitbetrachtung].[Zeitbetrachtung].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Zeitbetrachtung].[Zeitbetrachtung].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Zeitbetrachtung].[Zeitbetrachtung].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Kostenstelle].[Kostenstelle]">
                  <UName name="[Kostenstelle].[Kostenstelle].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Kostenstelle].[Kostenstelle].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Kostenstelle].[Kostenstelle].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Kostenstelle].[Kostenstelle].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Kostenstelle].[Kostenstelle].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Kostenstelle].[PNR]">
                  <UName name="[Kostenstelle].[PNR].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Kostenstelle].[PNR].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Kostenstelle].[PNR].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Kostenstelle].[PNR].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Kostenstelle].[PNR].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Kostenstelle].[Eintritt2]">
                  <UName name="[Kostenstelle].[Eintritt2].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Kostenstelle].[Eintritt2].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Kostenstelle].[Eintritt2].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Kostenstelle].[Eintritt2].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Kostenstelle].[Eintritt2].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Kostenstelle].[Eintritt]">
                  <UName name="[Kostenstelle].[Eintritt].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Kostenstelle].[Eintritt].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Kostenstelle].[Eintritt].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Kostenstelle].[Eintritt].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Kostenstelle].[Eintritt].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[KST].[KST]">
                  <UName name="[KST].[KST].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[KST].[KST].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[KST].[KST].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[KST].[KST].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[KST].[KST].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Person].[Person]">
                  <UName name="[Person].[Person].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Person].[Person].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Person].[Person].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Person].[Person].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Person].[Person].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Person].[Person Austritt]">
                  <UName name="[Person].[Person Austritt].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Person].[Person Austritt].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Person].[Person Austritt].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Person].[Person Austritt].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Person].[Person Austritt].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Person].[Person aktiv]">
                  <UName name="[Person].[Person aktiv].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Person].[Person aktiv].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Person].[Person aktiv].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Person].[Person aktiv].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Person].[Person aktiv].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[UserAccount].[UserAccount]">
                  <UName name="[UserAccount].[UserAccount].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[UserAccount].[UserAccount].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[UserAccount].[UserAccount].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[UserAccount].[UserAccount].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[UserAccount].[UserAccount].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[UserAccount].[Level 01 username]">
                  <UName name="[UserAccount].[Level 01 username].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[UserAccount].[Level 01 username].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[UserAccount].[Level 01 username].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[UserAccount].[Level 01 username].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[UserAccount].[Level 01 username].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[UserAccount].[Level 01 shortusername]">
                  <UName name="[UserAccount].[Level 01 shortusername].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[UserAccount].[Level 01 shortusername].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[UserAccount].[Level 01 shortusername].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[UserAccount].[Level 01 shortusername].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[UserAccount].[Level 01 shortusername].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Vertragszustand].[Vertragszustand]">
                  <UName name="[Vertragszustand].[Vertragszustand].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Vertragszustand].[Vertragszustand].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Vertragszustand].[Vertragszustand].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Vertragszustand].[Vertragszustand].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Vertragszustand].[Vertragszustand].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Kostenart].[Kostenart]">
                  <UName name="[Kostenart].[Kostenart].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Kostenart].[Kostenart].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Kostenart].[Kostenart].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Kostenart].[Kostenart].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Kostenart].[Kostenart].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
                <HierarchyInfo name="[Kostenart].[Level 02 Bezeichnung]">
                  <UName name="[Kostenart].[Level 02 Bezeichnung].[MEMBER_UNIQUE_NAME]" type="xsd:string"/>
                  <Caption name="[Kostenart].[Level 02 Bezeichnung].[MEMBER_CAPTION]" type="xsd:string"/>
                  <LName name="[Kostenart].[Level 02 Bezeichnung].[LEVEL_UNIQUE_NAME]" type="xsd:string"/>
                  <LNum name="[Kostenart].[Level 02 Bezeichnung].[LEVEL_NUMBER]" type="xsd:int"/>
                  <DisplayInfo name="[Kostenart].[Level 02 Bezeichnung].[DISPLAY_INFO]" type="xsd:unsignedInt"/>
                </HierarchyInfo>
              </AxisInfo>
            </AxesInfo>
            <CellInfo>
              <Value name="VALUE"/>
              <FmtValue name="FORMATTED_VALUE" type="xsd:string"/>
              <CellOrdinal name="CELL_ORDINAL" type="xsd:unsignedInt"/>
            </CellInfo>
          </OlapInfo>
          <Axes>
            <Axis name="Axis0">
              <Tuples/>
            </Axis>
            <Axis name="Axis1">
              <Tuples>
                <Tuple>
                  <Member Hierarchy="[Geschlecht].[Geschlecht]">
                    <UName>[Geschlecht].[Geschlecht].[weiblich]</UName>
                    <Caption>weiblich</Caption>
                    <LName>[Geschlecht].[Geschlecht].[Level 01]</LName>
                    <LNum>1</LNum>
                    <DisplayInfo>0</DisplayInfo>
                  </Member>
                </Tuple>
                <Tuple>
                  <Member Hierarchy="[Geschlecht].[Geschlecht]">
                    <UName>[Geschlecht].[Geschlecht].[m&#228;nnlich]</UName>
                    <Caption>m&#228;nnlich</Caption>
                    <LName>[Geschlecht].[Geschlecht].[Level 01]</LName>
                    <LNum>1</LNum>
                    <DisplayInfo>131072</DisplayInfo>
                  </Member>
                </Tuple>
              </Tuples>
            </Axis>
            <Axis name="SlicerAxis">
              <Tuples>
                <Tuple>
                  <Member Hierarchy="[Measures]">
                    <UName>[Measures].[Mitarbeiteranzahl]</UName>
                    <Caption>Mitarbeiteranzahl</Caption>
                    <LName>[Measures].[MeasuresLevel]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>0</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Zeit].[Monate]">
                    <UName>[Zeit].[Monate].[Alle]</UName>
                    <Caption>Alle</Caption>
                    <LName>[Zeit].[Monate].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>11</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Zeit].[Zeit]">
                    <UName>[Zeit].[Zeit].[Zeit Gesamt]</UName>
                    <Caption>Zeit Gesamt</Caption>
                    <LName>[Zeit].[Zeit].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>11</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Vertragsbefristung].[Vertragsbefristung]">
                    <UName>[Vertragsbefristung].[Vertragsbefristung].[Alle Vertragsbefristungen]</UName>
                    <Caption>Alle Vertragsbefristungen</Caption>
                    <LName>[Vertragsbefristung].[Vertragsbefristung].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>2</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Mitarbeitergruppe].[Mitarbeitergruppe]">
                    <UName>[Mitarbeitergruppe].[Mitarbeitergruppe].[Alle Mitarbeitergruppen]</UName>
                    <Caption>Alle Mitarbeitergruppen</Caption>
                    <LName>[Mitarbeitergruppe].[Mitarbeitergruppe].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>5</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Funktionsbezeichnung].[Funktionsbezeichnung]">
                    <UName>[Funktionsbezeichnung].[Funktionsbezeichnung].[Alle]</UName>
                    <Caption>Alle</Caption>
                    <LName>[Funktionsbezeichnung].[Funktionsbezeichnung].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>7</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Alter].[Alter]">
                    <UName>[Alter].[Alter].[jedes Alter]</UName>
                    <Caption>jedes Alter</Caption>
                    <LName>[Alter].[Alter].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>9</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Vertragsart].[Vertragsart]">
                    <UName>[Vertragsart].[Vertragsart].[Alle Vertragsarten]</UName>
                    <Caption>Alle Vertragsarten</Caption>
                    <LName>[Vertragsart].[Vertragsart].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>53</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit]">
                    <UName>[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit].[Alle Betriebszugeh&#246;rigkeiten]</UName>
                    <Caption>Alle Betriebszugeh&#246;rigkeiten</Caption>
                    <LName>[Betriebszugeh&#246;rigkeit].[Betriebszugeh&#246;rigkeit].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>10</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Standort].[Standort]">
                    <UName>[Standort].[Standort].[Alle Standorte]</UName>
                    <Caption>Alle Standorte</Caption>
                    <LName>[Standort].[Standort].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>3</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Zeitbetrachtung].[Zeitbetrachtung]">
                    <UName>[Zeitbetrachtung].[Zeitbetrachtung].[AP]</UName>
                    <Caption>AP</Caption>
                    <LName>[Zeitbetrachtung].[Zeitbetrachtung].[Zeitbetrachtung]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>0</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Kostenstelle].[Kostenstelle]">
                    <UName>[Kostenstelle].[Kostenstelle].[ Kieback&amp;Peter GmbH &amp; Co.KG]</UName>
                    <Caption> Kieback&amp;Peter GmbH &amp; Co.KG</Caption>
                    <LName>[Kostenstelle].[Kostenstelle].[Top]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>6</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Kostenstelle].[PNR]">
                    <UName>[Kostenstelle].[PNR].[All]</UName>
                    <Caption>All</Caption>
                    <LName>[Kostenstelle].[PNR].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>2586</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Kostenstelle].[Eintritt2]">
                    <UName>[Kostenstelle].[Eintritt2].[All]</UName>
                    <Caption>All</Caption>
                    <LName>[Kostenstelle].[Eintritt2].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>456</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Kostenstelle].[Eintritt]">
                    <UName>[Kostenstelle].[Eintritt].[All]</UName>
                    <Caption>All</Caption>
                    <LName>[Kostenstelle].[Eintritt].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>456</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[KST].[KST]">
                    <UName>[KST].[KST].[KST Gesamt]</UName>
                    <Caption>KST Gesamt</Caption>
                    <LName>[KST].[KST].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>374</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Person].[Person]">
                    <UName>[Person].[Person].[All]</UName>
                    <Caption>All</Caption>
                    <LName>[Person].[Person].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>2586</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Person].[Person Austritt]">
                    <UName>[Person].[Person Austritt].[Alle Personen]</UName>
                    <Caption>Alle Personen</Caption>
                    <LName>[Person].[Person Austritt].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>254</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Person].[Person aktiv]">
                    <UName>[Person].[Person aktiv].[Alle Personen]</UName>
                    <Caption>Alle Personen</Caption>
                    <LName>[Person].[Person aktiv].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>3</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[UserAccount].[UserAccount]">
                    <UName>[UserAccount].[UserAccount].[All]</UName>
                    <Caption>All</Caption>
                    <LName>[UserAccount].[UserAccount].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>65</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[UserAccount].[Level 01 username]">
                    <UName>[UserAccount].[Level 01 username].[All]</UName>
                    <Caption>All</Caption>
                    <LName>[UserAccount].[Level 01 username].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>65</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[UserAccount].[Level 01 shortusername]">
                    <UName>[UserAccount].[Level 01 shortusername].[All]</UName>
                    <Caption>All</Caption>
                    <LName>[UserAccount].[Level 01 shortusername].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>65</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Vertragszustand].[Vertragszustand]">
                    <UName>[Vertragszustand].[Vertragszustand].[Alle]</UName>
                    <Caption>Alle</Caption>
                    <LName>[Vertragszustand].[Vertragszustand].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>10</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Kostenart].[Kostenart]">
                    <UName>[Kostenart].[Kostenart].[Alle Kostenarten]</UName>
                    <Caption>Alle Kostenarten</Caption>
                    <LName>[Kostenart].[Kostenart].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>5</DisplayInfo>
                  </Member>
                  <Member Hierarchy="[Kostenart].[Level 02 Bezeichnung]">
                    <UName>[Kostenart].[Level 02 Bezeichnung].[Alle Kostenarten]</UName>
                    <Caption>Alle Kostenarten</Caption>
                    <LName>[Kostenart].[Level 02 Bezeichnung].[(All)]</LName>
                    <LNum>0</LNum>
                    <DisplayInfo>51</DisplayInfo>
                  </Member>
                </Tuple>
              </Tuples>
            </Axis>
          </Axes>
          <CellData/>
        </root>
      </return>
    </ExecuteResponse>
  </soap:Body>
</soap:Envelope>
"""


import unittest
from olap.xmla.formatreader import TupleFormatReader
import olap.xmla.utils as utils
import olap.xmla.xmla as xmla
import requests_mock
from . import mdx1
from . import mdx_noaxistuple
from . import mdx_columns_but_no_rows
from . import mdx_rows_but_no_columns_no_cells

"""
import olap.xmla.xmla as xmla
p = xmla.XMLAProvider()
c=p.connect(location="http://localhost:8080/xmondrian/xmla")
cmd="...."
res=c.Execute(cmd, Catalog="FoodMart")
"""
class TestFormatReader(unittest.TestCase):

    longMessage=True
    maxDiff = 2000
    def setUp(self):
        location = "http://somewhere/over/the/rainbow"
        p = xmla.XMLAProvider()
        c = p.connect(location=location)
        with requests_mock.mock() as m:
            m.post(location, text=mdx1.xml_response)
            self.fr = c.Execute(mdx1.__doc__)
        self.res = utils.PropDict(mdx1.result)
        
        self.cm = self.fr.cellmap
        self.ordinal1 = list(filter(lambda cell: cell._CellOrdinal == "1", self.res.CellData.Cell))[0]
        self.ax_tupel0 = [tup.Member for tup in self.res.Axes.Axis[0].Tuples.Tuple]

        with requests_mock.mock() as m:
            m.post(location, text=mdx_noaxistuple.xml_response)
            self.fr_noaxistuple = c.Execute(mdx_noaxistuple.__doc__)

        with requests_mock.mock() as m:
            m.post(location, text=mdx_columns_but_no_rows.xml_response)
            self.fr_cbnr = c.Execute(mdx_columns_but_no_rows.__doc__)

        with requests_mock.mock() as m:
            m.post(location, text=mdx_rows_but_no_columns_no_cells.xml_response)
            self.fr_rbncnc = c.Execute(mdx_rows_but_no_columns_no_cells.__doc__)

    def testOrdinalsToCells(self):
        self.assertIsInstance(self.cm, dict)

        # should be the same
        self.assertEqual(self.ordinal1, self.cm[1])

    def testGetCellByOrdinal(self):
        self.assertEqual(self.ordinal1, self.fr.getCellByOrdinal(1))
        self.assertEqual({}, self.fr.getCellByOrdinal(-1))

    def testGetAxisTuple(self):
        
        self.assertEqual(self.ax_tupel0, self.fr.getAxisTuple(0))
        self.assertEqual(self.ax_tupel0, self.fr.getAxisTuple("Axis0"))
        self.assertRaises(IndexError, self.fr.getAxisTuple, *[7])
        self.assertRaises(IndexError, self.fr.getAxisTuple, *["Axis7"])
        
        # if there are no axis information
        self.assertEqual(None, self.fr_noaxistuple.getAxisTuple("Axis0"))

        # some actually return empty tuples,
        # e.g. "select {} on columns, [Gender].[Gender].ALLMEMBERS on rows from [Sales]"
        # doesn't seem to work on mondrian anymore (throws NPE), still works on SSAS
        # which would have no tuples on Axis1

        self.assertEqual([], self.fr_rbncnc.getAxisTuple(0))

    def testGetSlice_without_SlicerAxis(self):
        c = {}
        fr = self.fr
        cm = fr.cellmap
        for (k,v) in cm.items(): c[k] = v.Value

        cube =[
            [c[0], c[1], c[2], c[3]],
            [c[4], c[5], c[6], c[7]]
            ]

        self.assertEqual(cube, fr.getSlice(properties="Value"), "whole")
        self.assertEqual(cube, fr.getSlice(properties="Value", SlicerAxis=1),
                          "whole, ignore SlicerAxis kw")

        cube =[
            [c[0], c[2], c[3]],
            [c[4], c[6], c[7]]
            ]

        self.assertEqual(cube, fr.getSlice(properties="Value", Axis0=[0,2,3]),
                          "come tuples from axis0, others fully")

        cube =[
            [c[0], c[2], c[3]]
            ]

        self.assertEqual(cube, fr.getSlice(properties="Value", Axis0=[0,2,3], Axis1=0),
                          "some tuples from all axes")

        self.assertEqual([], fr.getSlice(properties="Value", Axis0=[]), "dropping axis")

        # requesting non-existing tuples from an axis
        self.assertRaises(ValueError, fr.getSlice, **{"Axis0":[7]})

        # getting the whole cell
        cube =[
            [cm[0]] # cm instead of c
            ]

        self.assertEqual(cube, fr.getSlice(Axis0=0, Axis1=0), "whole cell")

        # getting more than one property cell
        cube =[[
                {"Value":cm[0]["Value"],
                 "FmtValue":cm[0]["FmtValue"]
                 }
                ]]
        self.assertEqual(cube, fr.getSlice(properties=["Value", "FmtValue"], 
                                            Axis0=0, Axis1=0), "few properties")

        # changing order
        cube =[
            [c[3], c[2], c[1]]
            ]

        self.assertEqual(cube, fr.getSlice(properties="Value", Axis0=[3,2,1], Axis1=0), 
                          "changing order")

    def testGetSlice_no_axes_1_cell(self):
        """ case: select from [Sales] """
        c = {}
        fr = self.fr_noaxistuple
        cm = fr.cellmap
        for (k,v) in cm.items(): c[k] = v.Value

        cube =c[0]

        self.assertEqual(cube, fr.getSlice(properties="Value"), "whole")
        self.assertEqual(cube, fr.getSlice(properties="Value", SlicerAxis=1), "whole1")
        self.assertEqual(cube, fr.getSlice(properties="Value", Axis0=0), "1st col")
        self.assertEqual(cube, fr.getSlice(properties="Value", Axis1=0), "1st row")
        self.assertEqual(cube, fr.getSlice(properties="Value", Axis0=[]), "no cols")

    def testGetSlice_columns_but_no_rows(self):
        """ case: select [Measures].AllMembers on columns from [Sales] """
        c = {}
        fr = self.fr_cbnr
        cm = fr.cellmap
        for (k,v) in cm.items(): c[k] = v.Value

        cube =[c[0], c[1]]

        self.assertEqual(cube, fr.getSlice(properties="Value"), "whole")
        self.assertEqual(cube, fr.getSlice(properties="Value", SlicerAxis=1), "whole1")
        cube =[c[0]]
        self.assertEqual(cube, fr.getSlice(properties="Value", Axis0=0), "1st col")
        cube =[c[0], c[1]]
        self.assertEqual(cube, fr.getSlice(properties="Value", Axis1=0), "1st row")
        cube =[]
        self.assertEqual(cube, fr.getSlice(properties="Value", Axis0=[]), "no cols")
        self.assertRaises(ValueError, fr.getSlice, **{"Axis0":[7]})

    def testGetSlice_columns_but_no_rows_and_no_cells(self):
        """
        works on SSAS:
        select {} on columns, [some hierarchy].ALLMEMBERS from [somecube]
        """
        c = {}
        fr = self.fr_rbncnc
        cm = fr.cellmap
        for (k,v) in cm.items(): c[k] = v.Value

        cube =[]

        self.assertEqual(cube, fr.getSlice(properties="Value"), "whole")
        self.assertEqual(cube, fr.getSlice(properties="Value", SlicerAxis=1), "whole1")
        self.assertEqual(cube, fr.getSlice(properties="Value", Axis0=[]), "no cols")





#-*- coding:utf-8 -*-

from setuptools import setup

long_description = open("README.md").read()

install_requires=[
    'olap >= 0.3',
    'netas-zeep',
    'requests',
    'lxml',
    'six'
    ]

setup(
    name='netas-xmla-with-dax',
    version='0.8.0',
    url="https://github.com/may-day/olap",
    license='Apache Software License 2.0',
    classifiers = [
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "Development Status :: 3 - Alpha",
        "Environment :: Web Environment",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules"
        ],
    description='Access olap data sources through xmla',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Norman Krämer',
    author_email='kraemer.norman@googlemail.com',
    packages=['olap', 'olap.xmla'],
    namespace_packages=['olap'],
    package_dir={'olap':'olap', 'olap.xmla': 'olap/xmla'},
    package_data={'olap.xmla': ['vs.wsdl']},
    install_requires=install_requires,
    tests_require = [
        'nose',
        'requests_mock',
    ],

    test_suite = 'nose.collector',

    include_package_data=True,
    zip_safe=False,
)
